<?php

namespace Drupal\config_enforce_devel\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\config_enforce_devel\Form\DevelFormHelperTrait;

/**
 * Defines a settings form for the Config Enforce Devel module.
 */
class SettingsForm extends ConfigFormBase {

  use DevelFormHelperTrait;

  const FORM_ID = 'config_enforce_devel_settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'config_enforce_devel.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $this->setSharedFormProperties($form, $form_state);

    $config = $this->config('config_enforce_devel.settings');
    $this->form()['available_modules'] = [
      '#type' => 'select',
      '#title' => $this->t('Select available modules'),
      '#description' => $this->t('These modules will be available on config forms, to specify where configuration files should be written. '),
      '#options' => $this->getAllModules(),
      '#multiple' => TRUE,
      '#default_value' => $config->get('available_modules'),
    ];
    return parent::buildForm($this->form(), $this->formState());
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->setSharedFormProperties($form, $form_state);

    $this->config('config_enforce_devel.settings')
      ->set('available_modules', $this->formState()->getValue('available_modules'))
      ->save();
    // @TODO Shouldn't we return here?
    parent::submitForm($this->form(), $this->formState());
  }

}
